@@ -34,7 +34,7 @@ def check_resp_items(item):
                     continue
     except Exception as err:
         print('日志参数处理异常 err=%s' % err)
-        if isinstance(item, (dict, str)):
+        if isinstance(item, str):
             if len(item) > 3000:
                 return item[:3000]
             else:
@@ -150,7 +150,7 @@ class MainLog(BaseLog):
                                    u'order_id': order_id,
                                    u'phone_num': phone_num}
                         message_body = json.dumps(message, ensure_ascii=False)
-                        self.debug('messagebody is %s' % message_body)
+                        # self.debug('messagebody is %s' % message_body)
                         if self.insert_log_queue:
                             self.insert_log_queue.insert_message(exchange=self.mq_exchange_name,
                                                                  body=message_body,
